// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package ebpf

import (
	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf/create"
	"github.com/apache/skywalking-cli/internal/commands/profiling/ebpf/keep"

	"github.com/urfave/cli/v2"
)

var Command = &cli.Command{
	Name:  "ebpf",
	Usage: "eBPF Profiling related sub-command",
	Subcommands: []*cli.Command{
		create.CreateCommand,
		keep.KeepCommand,
		ListTaskCommand,
		ListScheduleCommand,
		AnalyzationCommand,
	},
}
